get_dot_path

Function get_dot_path 

pub fn get_dot_path<'a>(value: &'a Value, path: &str) -> Option<&'a Value>
Get a nested value from a Value using dot-notation (e.g. “a.b.c”). Returns None if any segment along the path is missing.