set_dot_path

Function set_dot_path 

pub fn set_dot_path(root: Value, path: &str, new_value: Value) -> Result<Value>
Set a nested value in a Value using dot-notation. Creates intermediate objects along the path if they do not exist.